==> krusader-trinity-3.5.13.2.tar.xz: krusader-trinity-3.5.13.2/krusader/Dialogs/krprogress.h <==
/* This file is part of the KDE libraries
   Copyright (C) 2000 Matej Koss <koss@miesto.sk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

/** This file was modified for Krusader by Shie Erlich & Rafi Yanai **/

#ifndef __kr_progress_h__
#define __kr_progress_h__

#include <tqlabel.h>

#include <kio/global.h>

#include <kprogress.h>
#include <ksqueezedtextlabel.h>

#include <kio/progressbase.h>

#include <tqobject.h>

class KrProgress : public KIO::ProgressBase {
  Q_OBJECT
  TQ_OBJECT
public:

  KrProgress(KIO::Job* job);
  virtual ~KrProgress();

public slots:
  virtual void slotTotalSize( KIO::Job*, KIO::filesize_t bytes );
  virtual void slotTotalFiles( KIO::Job*, unsigned long files );
  virtual void slotTotalDirs( KIO::Job*, unsigned long dirs );

  virtual void slotProcessedSize( KIO::Job*, KIO::filesize_t bytes );
  virtual void slotProcessedFiles( KIO::Job*, unsigned long files );
  virtual void slotProcessedDirs( KIO::Job*, unsigned long dirs );

  virtual void slotSpeed( KIO::Job*, unsigned long bytes_per_second );
  virtual void slotPercent( KIO::Job*, unsigned long percent );
  virtual void slotInfoMessage( KIO::Job*, const TQString & msg );
	
	virtual void slotStop();
  virtual void closeEvent( TQCloseEvent* );

protected:
  void showTotals();
  void setDestVisible( bool visible );

  KSqueezedTextLabel* sourceLabel;
  KSqueezedTextLabel* destLabel;
  TQLabel* progressLabel;
  TQLabel* destInvite;
  TQLabel* speedLabel;
  TQLabel* sizeLabel;
  TQLabel* resumeLabel;

  KProgress* m_pProgressBar;

  KIO::filesize_t m_iTotalSize;
  unsigned long m_iTotalFiles;
  unsigned long m_iTotalDirs;

  KIO::filesize_t m_iProcessedSize;
  unsigned long m_iProcessedDirs;
  unsigned long m_iProcessedFiles;

protected:
  virtual void virtual_hook( int id, void* data );
};


#endif // __kr_progress_h__

==> krusader-trinity_14.0.11.orig.tar.xz: krusader-trinity-14.0.11/krusader/Dialogs/krprogress.h <==
/* This file is part of the KDE libraries
   Copyright (C) 2000 Matej Koss <koss@miesto.sk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

/** This file was modified for Krusader by Shie Erlich & Rafi Yanai **/

#ifndef __kr_progress_h__
#define __kr_progress_h__

#include <tqlabel.h>

#include <tdeio/global.h>

#include <kprogress.h>
#include <ksqueezedtextlabel.h>

#include <tdeio/progressbase.h>

#include <tqobject.h>

class KrProgress : public TDEIO::ProgressBase {
  Q_OBJECT
  
public:

  KrProgress(TDEIO::Job* job);
  virtual ~KrProgress();

public slots:
  virtual void slotTotalSize( TDEIO::Job*, TDEIO::filesize_t bytes );
  virtual void slotTotalFiles( TDEIO::Job*, unsigned long files );
  virtual void slotTotalDirs( TDEIO::Job*, unsigned long dirs );

  virtual void slotProcessedSize( TDEIO::Job*, TDEIO::filesize_t bytes );
  virtual void slotProcessedFiles( TDEIO::Job*, unsigned long files );
  virtual void slotProcessedDirs( TDEIO::Job*, unsigned long dirs );

  virtual void slotSpeed( TDEIO::Job*, unsigned long bytes_per_second );
  virtual void slotPercent( TDEIO::Job*, unsigned long percent );
  virtual void slotInfoMessage( TDEIO::Job*, const TQString & msg );
	
	virtual void slotStop();
  virtual void closeEvent( TQCloseEvent* );

protected:
  void showTotals();
  void setDestVisible( bool visible );

  KSqueezedTextLabel* sourceLabel;
  KSqueezedTextLabel* destLabel;
  TQLabel* progressLabel;
  TQLabel* destInvite;
  TQLabel* speedLabel;
  TQLabel* sizeLabel;
  TQLabel* resumeLabel;

  KProgress* m_pProgressBar;

  TDEIO::filesize_t m_iTotalSize;
  unsigned long m_iTotalFiles;
  unsigned long m_iTotalDirs;

  TDEIO::filesize_t m_iProcessedSize;
  unsigned long m_iProcessedDirs;
  unsigned long m_iProcessedFiles;

protected:
  virtual void virtual_hook( int id, void* data );
};


#endif // __kr_progress_h__
